summaryrefslogtreecommitdiffstats
path: root/MdePkg/Include/Protocol/ComponentName2.h
diff options
context:
space:
mode:
Diffstat (limited to 'MdePkg/Include/Protocol/ComponentName2.h')
-rw-r--r--MdePkg/Include/Protocol/ComponentName2.h32
1 files changed, 27 insertions, 5 deletions
diff --git a/MdePkg/Include/Protocol/ComponentName2.h b/MdePkg/Include/Protocol/ComponentName2.h
index bc6a903d15..7cec01699e 100644
--- a/MdePkg/Include/Protocol/ComponentName2.h
+++ b/MdePkg/Include/Protocol/ComponentName2.h
@@ -1,7 +1,9 @@
/** @file
- EFI Component Name 2 Protocol
+ UEFI Component Name 2 Protocol as defined in the UEFI 2.1 specification.
+ This protocol is used to retrieve user readable names of drivers
+ and controllers managed by UEFI Drivers.
- Copyright (c) 2006 - 2007, Intel Corporation
+ Copyright (c) 2006 - 2008, Intel Corporation
All rights reserved. This program and the accompanying materials
are licensed and made available under the terms and conditions of the BSD License
which accompanies this distribution. The full text of the license may be found at
@@ -31,7 +33,7 @@ typedef struct _EFI_COMPONENT_NAME2_PROTOCOL EFI_COMPONENT_NAME2_PROTOCOL;
the EFI Driver.
@param This A pointer to the
- EFI_COMPONENT_NAME_PROTOCOL instance.
+ EFI_COMPONENT_NAME2_PROTOCOL instance.
@param Language A pointer to a Null-terminated ASCII string
array indicating the language. This is the
@@ -76,7 +78,7 @@ EFI_STATUS
the controller that is being managed by an EFI Driver.
@param This A pointer to the
- EFI_COMPONENT_NAME_PROTOCOL instance.
+ EFI_COMPONENT_NAME2_PROTOCOL instance.
@param ControllerHandle The handle of a controller that the
driver specified by This is managing.
@@ -152,8 +154,28 @@ EFI_STATUS
);
//
// Interface structure for the Component Name Protocol
//
+/**
+ @par Protocol Description:
+ This protocol is used to retrieve user readable names of drivers
+ and controllers managed by UEFI Drivers.
+
+ @param GetDriverName
+ Retrieves a Unicode string that is the user readable name of the driver.
+
+ @param GetControllerName
+ Retrieves a Unicode string that is the user readable name of a
+ controller that is being managed by a driver.
+
+ @param SupportedLanguages
+ A Null-terminated ASCII string array that contains one or more
+ supported language codes. This is the list of language codes that
+ this protocol supports. The number of languages supported by a
+ driver is up to the driver writer. SupportedLanguages is
+ specified in RFC 3066 format.
+
+**/
struct _EFI_COMPONENT_NAME2_PROTOCOL {
EFI_COMPONENT_NAME2_GET_DRIVER_NAME GetDriverName;
EFI_COMPONENT_NAME2_GET_CONTROLLER_NAME GetControllerName;
@@ -152,8 +154,28 @@ EFI_STATUS
);
//
-// Interface structure for the Component Name Protocol
+// Interface structure for the Component Name2 Protocol
//